summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autofill/autofill_dialog.h
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-13 22:08:28 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-13 22:08:28 +0000
commitc113686bcc4c5019b6a97580c1b1ddd0ca56403e (patch)
tree13ad5961c608eab94eac73d5ea8a699c0aa50711 /chrome/browser/autofill/autofill_dialog.h
parent1d32bc88813cca868952dcb927c541f27331b4b3 (diff)
downloadchromium_src-c113686bcc4c5019b6a97580c1b1ddd0ca56403e.zip
chromium_src-c113686bcc4c5019b6a97580c1b1ddd0ca56403e.tar.gz
chromium_src-c113686bcc4c5019b6a97580c1b1ddd0ca56403e.tar.bz2
Implement a bare-bones AutoFill dialog for gtk.
BUG=18201 TEST=none Review URL: http://codereview.chromium.org/542045 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@36179 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autofill/autofill_dialog.h')
-rw-r--r--chrome/browser/autofill/autofill_dialog.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/autofill/autofill_dialog.h b/chrome/browser/autofill/autofill_dialog.h
index 49636fc..f1a5f5f 100644
--- a/chrome/browser/autofill/autofill_dialog.h
+++ b/chrome/browser/autofill/autofill_dialog.h
@@ -13,7 +13,8 @@
// |profiles| is a vector of autofill profiles that contains the current profile
// information. The dialog fills out the profile fields using this data. Any
// changes made to the profile information through the dialog should be
-// transferred back into |profiles|.
-void ShowAutoFillDialog(const std::vector<AutoFillProfile>& profiles);
+// transferred back into |profiles| and |credit_cards|.
+void ShowAutoFillDialog(std::vector<AutoFillProfile>* profiles,
+ std::vector<FormGroup>* credit_cards);
#endif // CHROME_BROWSER_AUTOFILL_AUTOFILL_DIALOG_H_